==> nextcloud-app-mail-0.7.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/en_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Loading accounts …" : "Loading accounts …",
    "Error while loading the accounts." : "Error whilst loading the accounts.",
    "Error while loading the selected account." : "Error whilst loading the selected account.",
    "Can not load this folder." : "Can not load this folder.",
    "Loading {folder}" : "Loading {folder}",
    "Searching for {query}" : "Searching for {query}",
    "Error while deleting message." : "Error whilst deleting message.",
    "Forwarded message" : "Forwarded message",
    "Choose a folder to store the attachment in" : "Choose a folder to store the attachment in",
    "Attachments saved to Files." : "Attachments saved to Files.",
    "Attachment saved to Files." : "Attachment saved to Files.",
    "Error while saving attachments to Files." : "Error whilst saving attachments to Files.",
    "Error while saving attachment to Files." : "Error whilst saving attachment to Files.",
    "Message flag could not be set." : "Message flag could not be set.",
    "Could not move message." : "Could not move message.",
    "Invalid account" : "Invalid account",
    "Invalid folder" : "Invalid folder",
    "Error while creating the account: " : "Error while creating the account: ",
    "Unknown error" : "Unknown error",
    "All inboxes" : "All inboxes",
    "you" : "you",
    "Send message to {email}" : "Send message to {email}",
    "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "We couldn’t load {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
    "We couldn’t load your message" : "We couldn’t load your message",
    "Unable to load the desired message" : "Unable to load the desired message",
    "There was a problem loading the message" : "There was a problem loading the message",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Show all folders" : "Show all folders",
    "Collapse folders" : "Collapse folders",
    "Error while deleting account." : "Error whilst deleting account.",
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "An error occurred while uploading {fname}" : "An error occurred while uploading {fname}",
    "Reply" : "Reply",
    "Send" : "Send",
    "Sending …" : "Sending…",
    "Message sent!" : "Message sent!",
    "Server error" : "Server error",
    "An unknown error occurred" : "An unknown error occurred",
    "Opening HTML drafts is not supported yet." : "Opening HTML drafts is not supported yet.",
    "Draft saved!" : "Draft saved!",
    "No writable calendars found" : "No writable calendars found",
    "Error while importing the calendar event" : "Error whilst importing the calendar event",
    "Error while downloading calendar event" : "Error whilst downloading calendar event",
    "Error while loading messages." : "Error whilst loading messages.",
    "Error while refreshing messages." : "Error while refreshing messages.",
    "Setting up your account" : "Setting up your account",
    "Inbox" : "Inbox",
    "Sent" : "Sent",
    "Drafts" : "Drafts",
    "Archive" : "Archive",
    "Trash" : "Trash",
    "Junk" : "Junk",
    "All" : "All",
    "Favorites" : "Favourites",
    "Creating account failed: " : "Creating account failed: ",
    "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
    "Delete permanently" : "Delete permanently",
    "& others" : "& others",
    "Error loading message" : "Error loading message",
    "Settings" : "Settings",
    "Forwarding to %s" : "Forwarding to %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Click here if you are not automatically redirected within the next few seconds.",
    "Redirect" : "Redirect",
    "The link leads to %s" : "The link leads to %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continue to %s",
    "Delete account" : "Delete account",
    "Try again" : "Try again",
    "New message" : "New message",
    "Account Settings" : "Account Settings",
    "Aliases" : "Aliases",
    "Mail address" : "Mail address",
    "Display Name" : "Display Name",
    "Save" : "Save",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
    "Compose new message" : "Compose new message",
    "Newer message" : "Newer message",
    "Older message" : "Older message",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle unread",
    "Delete" : "Delete",
    "Search" : "Search",
    "Refresh" : "Refresh",
    "Connect your mail account" : "Connect your mail account",
    "Name" : "Name",
    "Mail Address" : "Mail Address",
    "Password" : "Password",
    "Manual configuration" : "Manual configuration",
    "IMAP Host" : "IMAP Host",
    "IMAP security" : "IMAP security",
    "None" : "None",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP User",
    "IMAP Password" : "IMAP Password",
    "SMTP Host" : "SMTP Host",
    "SMTP security" : "SMTP security",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP User",
    "SMTP Password" : "SMTP Password",
    "Connect" : "Connect",
    "from" : "from",
    "to" : "to",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Subject",
    "Save all to Files" : "Save all to Files",
    "Add mail account" : "Add mail account",
    "No search results for" : "No search results for",
    "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
    "Show images from this sender" : "Show images from this sender",
    "Forward" : "Forward",
    "Add attachment" : "Add attachment",
    "Add from Files" : "Add from Files",
    "Import into calendar" : "Import into calendar",
    "Download attachment" : "Download attachment",
    "Save to Files" : "Save to Files"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/en_GB.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Loading accounts" : "Loading accounts",
    "Error while loading the accounts." : "Error whilst loading the accounts.",
    "Error while loading the selected account." : "Error whilst loading the selected account.",
    "Can not load this folder." : "Can not load this folder.",
    "Searching for {query}" : "Searching for {query}",
    "Error while deleting message." : "Error whilst deleting message.",
    "Forwarded message" : "Forwarded message",
    "Choose a folder to store the attachment in" : "Choose a folder to store the attachment in",
    "Attachments saved to Files." : "Attachments saved to Files.",
    "Attachment saved to Files." : "Attachment saved to Files.",
    "Error while saving attachments to Files." : "Error whilst saving attachments to Files.",
    "Error while saving attachment to Files." : "Error whilst saving attachment to Files.",
    "Message flag could not be set." : "Message flag could not be set.",
    "Could not move message." : "Could not move message.",
    "Invalid account" : "Invalid account",
    "Invalid folder" : "Invalid folder",
    "Error while creating the account: " : "Error while creating the account: ",
    "Unknown error" : "Unknown error",
    "All inboxes" : "All inboxes",
    "you" : "you",
    "Send message to {email}" : "Send message to {email}",
    "Could not load {tag}{name}{endtag}" : "Could not load {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "We couldn’t load {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "There was a problem loading {tag}{name}{endtag}",
    "We couldn’t load your message" : "We couldn’t load your message",
    "Unable to load the desired message" : "Unable to load the desired message",
    "There was a problem loading the message" : "There was a problem loading the message",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n new message \nfrom {from}","%n new messages \nfrom {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Show all folders" : "Show all folders",
    "Collapse folders" : "Collapse folders",
    "Error while deleting account." : "Error whilst deleting account.",
    "Choose a file to add as attachment" : "Choose a file to add as attachment",
    "An error occurred while uploading {fname}" : "An error occurred while uploading {fname}",
    "Reply" : "Reply",
    "Send" : "Send",
    "Sending …" : "Sending…",
    "Message sent!" : "Message sent!",
    "Server error" : "Server error",
    "An unknown error occurred" : "An unknown error occurred",
    "Opening HTML drafts is not supported yet." : "Opening HTML drafts is not supported yet.",
    "Draft saved!" : "Draft saved!",
    "No writable calendars found" : "No writable calendars found",
    "Error while importing the calendar event" : "Error whilst importing the calendar event",
    "Error while downloading calendar event" : "Error whilst downloading calendar event",
    "Error while loading messages." : "Error whilst loading messages.",
    "Error while refreshing messages." : "Error while refreshing messages.",
    "Setting up your account" : "Setting up your account",
    "Inbox" : "Inbox",
    "Sent" : "Sent",
    "Drafts" : "Drafts",
    "Archive" : "Archive",
    "Trash" : "Trash",
    "Junk" : "Junk",
    "All" : "All",
    "Favorites" : "Favourites",
    "Auto detect failed. Please use manual mode." : "Auto detect failed. Please use manual mode.",
    "Creating account failed: " : "Creating account failed: ",
    "Delete permanently" : "Delete permanently",
    "& others" : "& others",
    "Error loading message" : "Error loading message",
    "Settings" : "Settings",
    "Forwarding to %s" : "Forwarding to %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Click here if you are not automatically redirected within the next few seconds.",
    "Redirect" : "Redirect",
    "The link leads to %s" : "The link leads to %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
    "Continue to %s" : "Continue to %s",
    "Delete account" : "Delete account",
    "Try again" : "Try again",
    "New message" : "New message",
    "Account Settings" : "Account Settings",
    "Aliases" : "Aliases",
    "Mail address" : "Mail address",
    "Display Name" : "Display Name",
    "Save" : "Save",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Speed up your Mail experience with these quick shortcuts." : "Speed up your Mail experience with these quick shortcuts.",
    "Compose new message" : "Compose new message",
    "Newer message" : "Newer message",
    "Older message" : "Older message",
    "Toggle star" : "Toggle star",
    "Toggle unread" : "Toggle unread",
    "Delete" : "Delete",
    "Search" : "Search",
    "Refresh" : "Refresh",
    "Connect your mail account" : "Connect your mail account",
    "Name" : "Name",
    "Mail Address" : "Mail Address",
    "Password" : "Password",
    "Manual configuration" : "Manual configuration",
    "IMAP Host" : "IMAP Host",
    "IMAP security" : "IMAP security",
    "None" : "None",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP User",
    "IMAP Password" : "IMAP Password",
    "SMTP Host" : "SMTP Host",
    "SMTP security" : "SMTP security",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP User",
    "SMTP Password" : "SMTP Password",
    "Connect" : "Connect",
    "from" : "from",
    "to" : "to",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Subject",
    "Save all to Files" : "Save all to Files",
    "Add mail account" : "Add mail account",
    "No search results for" : "No search results for",
    "The images have been blocked to protect your privacy." : "The images have been blocked to protect your privacy.",
    "Show images from this sender" : "Show images from this sender",
    "Forward" : "Forward",
    "No messages in this folder!" : "No messages in this folder!",
    "Upload attachment" : "Upload attachment",
    "Add attachment from Files" : "Add attachment from Files",
    "Import into calendar" : "Import into calendar",
    "Download attachment" : "Download attachment",
    "Save to Files" : "Save to Files"
},
"nplurals=2; plural=(n != 1);");
